pub trait Validate<T: ?Sized>:
'static
+ Send
+ Sync {
// Required methods
fn describe(&self, formatter: &mut Formatter<'_>) -> Result;
fn validate(&self, target: &T) -> Result<(), ErrorWithOrigin>;
}Expand description
Generic post-validation for a configuration parameter or a config.
Implementations
Validations are implemented for the following types:
NotEmpty. Validates that a string or a collection, such asVec, is not empty.Range,RangeInclusiveetc. Validates whether the type is within the provided bounds.
Required Methods